##  Related Information
[Obsolescence Risk Management](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management?locale=en-US&version=CLOUD "https://help.sap.com/docs/leanix/ea/obsolescence-risk-management?locale=en-US&version=CLOUD")
YesNo
Send
Help us provide a better digital experience for you and all other visitors.
What is the purpose of your visit to our website today?
  * Understand software features and benefits for a possible purchase
  * Find information about how to use the software
  * Find implementation or configuration information
  * Find information on installing or upgrading the software
  * Find information to troubleshoot and resolve issues that I'm encountering
  * Find developer or API information
  * Learn about new or updated product features
  * Other (please specify)


You can write a maximum of 255 characters.
Were you able to complete your task?
  * Yes
  * No


Why were you not able to complete your task today?
You can write a maximum of 4000 characters.
